==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/pt-PT/admin/users/table.php <==
<?php

return array(
    'activated'  			=> 'Ativo',
    'allow'  				=> 'Permitir',
    'checkedout'  			=> 'Artigos',
    'created_at' 			=> 'Criado em',
    'createuser' 			=> 'Criar Utilizador',
    'deny'  				=> 'Recusar',
    'email'      			=> 'Email',
    'employee_num'      	=> 'Funcionário Nº',
    'first_name' 			=> 'Nome',
    'groupnotes'			=> 'Selecione um grupo a atribuir ao utilizador. O utilizador assume as permissões do grupo ao qual é associado.',
    'id'         			=> 'Id',
    'inherit'  				=> 'Herdar',
    'job' 					=> 'Cargo',
    'last_login'  			=> 'Último início de sessão',
    'last_name'  			=> 'Apelido',
    'location'  			=> 'Localização',
    'lock_passwords'		=> 'Detalhes de autenticação não podem ser alterados nesta instalação.',
    'manager' 				=> 'Responsável',
    'managed_locations'     => 'Locais gerenciados',
    'name' 					=> 'Nome',
    'notes'                 => 'Notas',
    'password_confirm' 		=> 'Confirmar palavra-passe',
    'password' 				=> 'Password',
    'phone'  				=> 'Telefone',
    'show_current'          => 'Mostrar Utilizadores Ativos',
    'show_deleted'          => 'Mostrar Utilizadores Removidos',
    'title' 				=> 'Título',
	'to_restore_them'		=> 'para restaurá-los.',
    'updateuser' 			=> 'Atualizar utilizador',
    'username' 				=> 'Nome de utilizador',
	'user_deleted_text' 	=> 'Este usuário foi marcado como excluído.',
    'username_note' 		=> '(Isto é usado apenas para vinculação com a Active Directory, para para login)',
    'cloneuser'             => 'Clonar Utilizador',
    'viewusers' 			=> 'Ver Utilizadores',
);

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/pt-PT/admin/users/table.php <==
<?php

return array(
    'activated'  			=> 'Ativo',
    'allow'  				=> 'Permitir',
    'checkedout'  			=> 'Artigos',
    'created_at' 			=> 'Criado em',
    'createuser' 			=> 'Criar Utilizador',
    'deny'  				=> 'Recusar',
    'email'      			=> 'Email',
    'employee_num'      	=> 'Funcionário Nº',
    'first_name' 			=> 'Nome',
    'groupnotes'			=> 'Selecione um grupo para atribuir ao utilizador, lembre-se que um utilizador tem as permissões do grupo que ele está atribuído. Use ctrl+click (ou cmd+clique no MacOS) para desmarcar os grupos.',
    'id'         			=> 'Id',
    'inherit'  				=> 'Herdar',
    'job' 					=> 'Cargo',
    'last_login'  			=> 'Último início de sessão',
    'last_name'  			=> 'Apelido',
    'location'  			=> 'Localização',
    'lock_passwords'		=> 'Detalhes de autenticação não podem ser alterados nesta instalação.',
    'manager' 				=> 'Responsável',
    'managed_locations'     => 'Locais gerenciados',
    'managed_users'         => 'Usuários gerenciados',
    'name' 					=> 'Nome',
    'nogroup'               => 'Nenhum grupo foi criado ainda. Para adicionar um, visite: ',
    'notes'                 => 'Notas',
    'password_confirm' 		=> 'Confirmar palavra-passe',
    'password' 				=> 'Password',
    'phone'  				=> 'Telefone',
    'show_current'          => 'Mostrar Utilizadores Ativos',
    'show_deleted'          => 'Mostrar Utilizadores Removidos',
    'title' 				=> 'Título',
	'to_restore_them'		=> 'para restaurá-los.',
    'total_assets_cost'     => "Custo Total de Ativos",
    'updateuser' 			=> 'Atualizar utilizador',
    'username' 				=> 'Nome de utilizador',
	'user_deleted_text' 	=> 'Este usuário foi marcado como excluído.',
    'username_note' 		=> '(Isto é usado apenas para vinculação com a Active Directory, para para login)',
    'cloneuser'             => 'Clonar Utilizador',
    'viewusers' 			=> 'Ver Utilizadores',
);
